##  Editing in the Report
Upon clicking on any Fact Sheet the edit pane will open on the right displaying more information about the Fact Sheet, Business Capability, Provider and Consumer Applications, etc. Within the edit pane, users are able to quickly modify Tags, attributes, and relations to Fact Sheets. Any adjustments made are immediately implemented within both the report and the Fact Sheet itself. Alternatively, you can navigate to the source Fact Sheet by clicking on the Fact Sheet name in the edit pane.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2751ae467a4410148714e860ba47c6d4_LowRes.png)
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
